# Reference Documentation

Technical specifications and quick lookups for the MCP Registry.

## API Reference

- [Generic Registry API](./api/generic-registry-api.md)
- [Registry Authorization](./api/registry-authorization.md)
- [Official Registry API](./api/official-registry-api.md)

## server.json Reference

- [Generic server.json Format](./server-json/generic-server-json.md)
- [Official Registry Requirements](./server-json/official-registry-requirements.md)

## CLI Reference

- [Commands](./cli/commands.md)

## Quick Reference

- [FAQ](./faq.md)